% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/functions.R
\name{reassignAlleles}
\alias{reassignAlleles}
\title{Correct allele calls based on a personalized genotype}
\usage{
reassignAlleles(clip_db, genotype_db)
}
\arguments{
\item{clip_db}{a \code{data.frame} containing V allele calls from a
single subject under \code{"V_CALL"} and the sample
IMGT-gapped V(D)J sequences under
\code{"SEQUENCE_IMGT"}}

\item{genotype_db}{a vector of named nucleotide germline sequences
                        matching the calls detailed in \code{allele_calls}
                        and personalized to the subject}
}
\value{
a single-column \code{data.frame} corresponding to \code{clip.db}
          and containing the best allele call from among the sequences
          listed in \code{genotype_db}
}
\description{
\code{reassignAlleles} uses a subject-specific genotype to correct
correct preliminary allele assignments of a set of sequences derived
from a single subject.
}
\details{
In order to save time, initial gene assignments are preserved and
the allele calls are chosen from among those provided in \code{genotype_db},
based on a simple alignment to the sample sequence.
}
\examples{
# Load example data
data(germline_ighv)
data(sample_db)

# Infer genotype from the sample
novel_df = findNovelAlleles(sample_db, germline_ighv)
geno = inferGenotype(sample_db, find_unmutated = TRUE,
                     germline_db = germline_ighv, novel_df = novel_df)

# Find the sequences that correspond to the genotype
genotype_seqs = genotypeFasta(geno, germline_ighv, novel_df)

# Use the personlized genotype to determine corrected allele assignments
V_CALL_GENOTYPED = reassignAlleles(sample_db, genotype_seqs)
sample_db = bind_cols(sample_db, V_CALL_GENOTYPED)
}

